@@ -221,31 +221,15 @@ def index(db, blacklist, indexer, args, options):
 
 
 def prune(db, blacklist, args, options):
-    fingerprints = set()
+    if "random" in options:
+        randomize = True
+    else:
+        randomize = False
 
     logging.info("Pruning database")
+
     db.connect()
-    urls = db.get_urls()
-
-    if "random" in options:
-        random.shuffle(urls)
-
-    for url in urls:
-        target = Target(url)
-
-        fingerprint = generate_fingerprint(target)
-        if fingerprint in fingerprints or db.get_scanned(fingerprint):
-            logging.debug("Marking scanned (matches fingerprint of another target): %s", target.url)
-            db.mark_scanned(target.url)
-            continue
-
-        if blacklist.match(target):
-            logging.debug("Deleting (matches blacklist pattern): %s", target.url)
-            db.delete_target(target.url)
-            continue
-
-        fingerprints.add(fingerprint)
-
+    db.prune(blacklist, randomize)
     db.close()
 
 
@@ -298,7 +282,7 @@ def generate_fingerprint(target):
         split = param.split("=", 1)
         if len(split) == 2 and split[1]:
             params.append(split[0])
-    fingerprint = "|".join((netloc, depth, page, ",".join(sorted(params))))
+    fingerprint = "|".join((netloc, depth, ",".join(sorted(params))))
     return generate_hash(fingerprint)
 
 
@@ -345,7 +329,11 @@ class TargetDatabase:
             self.insert = "INSERT OR REPLACE"
             self.conflict = ""
 
-        self.module = importlib.import_module(module_name, package=None)
+        try:
+            self.module = importlib.import_module(module_name, package=None)
+        except ModuleNotFoundError:
+            logging.error("Failed to load required module - %s", module_name)
+            sys.exit(1)
 
         if self.module.paramstyle == "qmark":
             self.param = "?"
@@ -413,8 +401,8 @@ class TargetDatabase:
                     url = row[0]
                     target = Target(url)
                     fingerprint = generate_fingerprint(target)
-                    self.mark_scanned(url)
-                    if self.get_scanned(fingerprint):
+                    self.mark_scanned(url, c)
+                    if self.get_scanned(fingerprint, c):
                         logging.debug("Skipping (matches fingerprint of previous scan): %s", target.url)
                         continue
                     else:
@@ -451,27 +439,38 @@ class TargetDatabase:
             logging.error("Failed to delete target - %s", str(e))
             sys.exit(1)
 
-    def get_scanned(self, fingerprint):
-        try:
-            with self.db, closing(self.db.cursor()) as c:
-                c.execute("SELECT fingerprint FROM fingerprints WHERE fingerprint = (%s)" % self.param, (fingerprint,))
-                row = c.fetchone()
-        except self.module.Error as e:
-            logging.error("Failed to look up fingerprint - %s", str(e))
-            sys.exit(1)
+    def get_scanned(self, fingerprint, cursor):
+        for i in range(3):
+            try:
+                cursor.execute("SELECT fingerprint FROM fingerprints WHERE fingerprint = (%s)" % self.param, (fingerprint,))
+                row = cursor.fetchone()
+                break
+            except self.module.Error as e:
+                if "connection already closed" in str(e) or "server closed the connection unexpectedly" in str(e):
+                    logging.warning("Failed to look up fingerprint (retrying) - %s", str(e))
+                    self.connect()
+                    continue
+                else:
+                    logging.error("Failed to look up fingerprint - %s", str(e))
+                    sys.exit(1)
 
         if row:
             return row[0]
         else:
             return False
 
-    def mark_scanned(self, url):
-        try:
-            with self.db, closing(self.db.cursor()) as c:
-                c.execute("UPDATE targets SET scanned = 1 WHERE url = %s" % (self.param,), (url,))
-        except self.module.Error as e:
-            logging.error("Failed to mark target as scanned - %s", str(e))
-            sys.exit(1)
+    def mark_scanned(self, url, cursor):
+        for i in range(3):
+            try:
+                cursor.execute("UPDATE targets SET scanned = 1 WHERE url = %s" % (self.param,), (url,))
+            except self.module.Error as e:
+                if "connection already closed" in str(e) or "server closed the connection unexpectedly" in str(e):
+                    logging.warning("Failed to mark target as scanned (retrying) - %s", str(e))
+                    self.connect()
+                    continue
+                else:
+                    logging.error("Failed to mark target as scanned - %s", str(e))
+                    sys.exit(1)
 
     def flush_fingerprints(self):
         logging.info("Flushing fingerprints")
@@ -492,6 +491,31 @@ class TargetDatabase:
             logging.error("Failed to flush targets - %s", str(e))
             sys.exit(1)
 
+    def prune(self, blacklist, randomize=False):
+        fingerprints = set()
+
+        urls = self.get_urls()
+
+        if randomize:
+            random.shuffle(urls)
+
+        for url in urls:
+            target = Target(url)
+
+            fingerprint = generate_fingerprint(target)
+            with self.db, closing(self.db.cursor()) as c:
+                if fingerprint in fingerprints or self.get_scanned(fingerprint, c):
+                    logging.debug("Marking scanned (matches fingerprint of another target): %s", target.url)
+                    self.mark_scanned(target.url, c)
+                    continue
+
+            if blacklist.match(target):
+                logging.debug("Deleting (matches blacklist pattern): %s", target.url)
+                self.delete_target(target.url)
+                continue
+
+            fingerprints.add(fingerprint)
+
 
 class Target:
     def __init__(self, url):
