@@ -109,7 +109,16 @@ def get_page(domain, index, data, retries, page):
             response_str = response_str.read().decode("utf-8")
             response = response_str.splitlines()
         except (HTTPError, IncompleteRead) as e:
-            if i == retries - 1:
+            if type(e).__name__ == "HTTPError" and e.code == 404:
+                response_str = e.read().decode("utf-8")
+                if "message" in response_str:
+                    response = json.loads(response_str)
+                    message = response["message"]
+                else:
+                    message = str(e)
+                logging.warn("Failed to fetch results (page %d) - %s", page, message)
+                return set()
+            elif i == retries - 1:
                 logging.error("Failed to fetch results (page %d, retries exceeded) - %s", page, str(e))
                 sys.exit(1)
             else:
@@ -134,9 +143,9 @@ def get_page(domain, index, data, retries, page):
     return results
 
 
-def get_results(domain, index, data, num_pages, threads, retries):
+def get_results(domain, index, data, num_pages, num_threads, retries):
     try:
-        executor = ThreadPoolExecutor(max_workers=threads)
+        executor = ThreadPoolExecutor(max_workers=num_threads)
         threads = executor.map(get_page, repeat(domain), repeat(index), repeat(data), repeat(retries), range(num_pages))
     except Exception:
         logging.error("Failed to execute threads")
